@@ -1,5 +1,5 @@
 package Catalyst::Controller::DBIC::API;
-$Catalyst::Controller::DBIC::API::VERSION = '2.007001';
+$Catalyst::Controller::DBIC::API::VERSION = '2.007002';
 #ABSTRACT: Provides a DBIx::Class web service automagically
 use Moose;
 BEGIN { extends 'Catalyst::Controller'; }
@@ -74,7 +74,6 @@ sub deserialize : Chained('setup') : CaptureArgs(0) : PathPart('') :
 
             # find out if CGI::Expand was involved
             if ( ref $req_params->{$param} eq 'HASH' ) {
-                $c->log->debug("Param '$param' decoded using CGI::Expand");
                 for my $key ( keys %{ $req_params->{$param} } ) {
 
                     # copy the value because JSON::XS will alter it
@@ -92,7 +91,6 @@ sub deserialize : Chained('setup') : CaptureArgs(0) : PathPart('') :
                 }
             }
             else {
-                $c->log->debug("Param '$param' decoded using JSON");
                 try {
                     my $value        = $req_params->{$param};
                     my $deserialized = $self->_json->decode($value);
@@ -216,9 +214,7 @@ sub object_lookup {
     my ( $self, $c, $id ) = @_;
 
     die 'No valid ID provided for look up' unless defined $id and length $id;
-    #my $object = $c->req->current_result_set->find($id);
-    # TODO: limit to configured (select) columns
-    my $object = $c->req->current_result_set->find($id, { %{$c->req->search_attributes}{qw(select as)} });
+    my $object = $c->req->current_result_set->find($id);
     die "No object found for id '$id'" unless defined $object;
     return $object;
 }
@@ -392,17 +388,12 @@ sub validate_object {
         }
     );
 
-    use Data::Dumper::Concise;
-    $c->log->debug('requires: ' . Dumper(\%requires_map) . 'allows: ' . Dumper(\%allows_map));
-
     foreach my $key ( keys %allows_map ) {
-        $c->log->debug("checking $key");
 
         # check value defined if key required
         my $allowed_fields = $allows_map{$key};
 
         if ( ref $allowed_fields ) {
-            $c->log->debug("$key is a relationship");
             my $related_source = $object->result_source->related_source($key);
             my $related_params = $params->{$key};
             my %allowed_related_map = map { $_ => 1 } @$allowed_fields;
@@ -418,17 +409,14 @@ sub validate_object {
                     )
                     )
                 {
-                    $c->log->debug("$key: $related_col");
                     $values{$key}{$related_col} = $related_col_value;
                 }
             }
         }
         else {
-            $c->log->debug("$key is a column");
             my $value = $params->{$key};
 
             if ( $requires_map{$key} ) {
-                $c->log->debug("$key is required");
                 unless ( defined($value) ) {
 
                     # if not defined look for default
@@ -510,14 +498,12 @@ sub update_object_from_params {
     foreach my $key ( keys %$params ) {
         my $value = $params->{$key};
         if ( ref($value) && !( reftype($value) eq reftype(JSON::MaybeXS::true) ) ) {
-            $c->log->debug("$key is a relationship");
             $self->update_object_relation( $c, $object,
                 delete $params->{$key}, $key );
         }
 
         # accessor = colname
         elsif ( $object->can($key) ) {
-            $c->log->debug("$key is an accessor");
             $object->$key($value);
         }
 
@@ -525,7 +511,6 @@ sub update_object_from_params {
         else {
             my $accessor =
                 $object->result_source->column_info($key)->{accessor};
-            $c->log->debug("$key with accessor $accessor");
             $object->$accessor($value);
         }
     }
@@ -537,7 +522,6 @@ sub update_object_from_params {
 sub update_object_relation {
     my ( $self, $c, $object, $related_params, $relation ) = @_;
     my $row = $object->find_related( $relation, {}, {} );
-    $c->log->debug("in update_object_relation");
 
     if ($row) {
         foreach my $key ( keys %$related_params ) {
@@ -563,26 +547,24 @@ sub update_object_relation {
         $row->update();
     }
     else {
-        $c->log->debug("create_related '$relation' called");
         $object->create_related( $relation, $related_params );
     }
 }
 
 
 sub insert_object_from_params {
-    my ($self, $c, $object, $params) = @_;
-    #my ( $self, undef, $object, $params ) = @_;
+
+    #my ($self, $c, $object, $params) = @_;
+    my ( $self, undef, $object, $params ) = @_;
 
     my %rels;
     while ( my ( $key, $value ) = each %{$params} ) {
         if ( ref($value) && !( reftype($value) eq reftype(JSON::MaybeXS::true) ) ) {
-            $c->log->debug("$key is a relationship");
             $rels{$key} = $value;
         }
 
         # accessor = colname
         elsif ( $object->can($key) ) {
-            $c->log->debug("$key is an accessor");
             $object->$key($value);
         }
 
@@ -590,7 +572,6 @@ sub insert_object_from_params {
         else {
             my $accessor =
                 $object->result_source->column_info($key)->{accessor};
-            $c->log->debug("$key with accessor $accessor");
             $object->$accessor($value);
         }
     }
@@ -638,7 +619,6 @@ sub end : Private {
         if ( $self->return_object
             && $c->req->has_objects
             && ! exists $c->stash->{ $self->stash_key }->{ $self->data_root } ) {
-            $c->log->debug('adding object data to response because return_object is enabled');
             my $returned_objects = [];
             push( @$returned_objects, $self->each_object_inflate( $c, $_ ) )
                 for map { $_->[0] } $c->req->all_objects;
@@ -647,9 +627,6 @@ sub end : Private {
                 ? $returned_objects
                 : $returned_objects->[0];
         }
-        else {
-            $c->log->debug('not adding object data to response because return_object is disabled');
-        }
     }
     else {
         $c->stash->{ $self->stash_key }->{success} =
@@ -722,7 +699,7 @@ Catalyst::Controller::DBIC::API - Provides a DBIx::Class web service automagical
 
 =head1 VERSION
 
-version 2.007001
+version 2.007002
 
 =head1 SYNOPSIS
 
